type UseGeolocationOptions = Partial<PositionOptions> & {
    /**
     * Whether to start the watcher immediately upon creation. If set to `false`, the watcher
     * will only start tracking the position when `resume()` is called.
     *
     * @defaultValue true
     */
    immediate?: boolean;
};
type WritableProperties<T> = {
    -readonly [P in keyof T]: T[P];
};
/**
 * Reactive access to the browser's [Geolocation API](https://developer.mozilla.org/en-US/docs/Web/API/Geolocation_API).
 *
 * @see https://runed.dev/docs/utilities/use-geolocation
 */
export declare function useGeolocation(options?: UseGeolocationOptions): {
    readonly isSupported: boolean;
    readonly coords: WritableProperties<Omit<GeolocationCoordinates, "toJSON">>;
    readonly locatedAt: number | null;
    readonly error: GeolocationPositionError | null;
    readonly isPaused: boolean;
    resume: () => void;
    pause: () => void;
};
export {};
